using WebAPI.Models;
using WebAPI.Services;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Authorization;

namespace WebAPI.Controllers;

[ApiController]
[Route("[controller]")]
public class GuestController : ControllerBase
{
    private readonly GuestService _guestService;

    public GuestController(GuestService guestService)
    {
        _guestService = guestService;
    }

    // GET all guest
    [HttpGet]
    [Authorize(Roles = "Admin")]
    public ActionResult<List<Guest>> GetAll()
    {
        var guests = _guestService.GetAll();
        return Ok(guests);
    }

    [HttpGet("sharedExperience/{sharedExperienceName}")]
    [Authorize(Roles = "Manager,Admin")]
    public ActionResult<List<Guest>> GetGuestsBySharedExperience(string sharedExperienceName)
    {

        var guests = _guestService.GetGuestsForSharedExperience(sharedExperienceName).Select(g => new
        {
            g.Name,
        }).ToList();
        return Ok(guests);
    }

    [HttpGet("experience/{experienceName}")]
    [Authorize(Roles = "Manager,Admin")]
    public ActionResult<List<Guest>> GetGuestsByExperience(string experienceName)
    {
   
        var guests = _guestService.GetGuestsForExperience(experienceName).Select(g => new
        {
            g.Name,
        }).ToList();
        return Ok(guests);
    }

}
