using WebAPI.Models;
using WebAPI.Services;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Authorization;

namespace WebAPI.Controllers;

[ApiController]
[Route("[controller]")]
public class ProviderController : ControllerBase
{
    private readonly ProviderService _providerService;

    public ProviderController(ProviderService providerService)
    {
        _providerService = providerService;
    }

    //GET action to get all
    //Only available for managers and admins
    [HttpGet]
    [Authorize(Roles = "Manager,Admin")]
    public ActionResult<List<Provider>> GetAllProviders()
    {
        var providers = _providerService
        .GetAll()
        .Select(p => new
        {
            p.Address,
            p.PhoneNumber,
            p.Permission
        })
        .ToList();
        return Ok(providers);
    }
}