using WebAPI.Models;
using WebAPI.Services;
using Microsoft.AspNetCore.Mvc;
using System.Linq;
using Microsoft.AspNetCore.Authorization;

namespace WebAPI.Controllers;

[ApiController]
[Route("[controller]")]
public class SharedExperienceController : ControllerBase
{
    private readonly SharedExperienceService _sharedExperienceService;
    private readonly GuestService _guestService;

    public SharedExperienceController(SharedExperienceService sharedExperienceService, GuestService guestService)
    {
        _sharedExperienceService = sharedExperienceService;
        _guestService = guestService;

    }

    //GET action to get name and date for all shared experiences
    [HttpGet]
    public ActionResult<List<SharedExperience>> GetAllSharedExperiences()
    {
        var sharedExperiences = _sharedExperienceService
        .GetAll()
        .OrderByDescending(s => s.Date)
        .Select(s => new
        {
            s.Name,
            s.Date
        })
        .ToList();
        return Ok(sharedExperiences);
    }

    //GET action to get all number of guests for shared experiences
    [HttpGet("GetGroupSizeForDiscount")]
    [Authorize(Roles = "Admin")]
    public ActionResult<List<object>> GetGroupSizeForDiscount()
    {
        var discounts = _sharedExperienceService.GetAll()
            .Select(se => new
            {
                SharedExperienceName = se.Name,
                GroupSize = se.Guests.Select(g => g.GuestId).Distinct().Count(),
                VolumeDiscount = se.Guests.Select(g => g.GuestId).Distinct().Count() >= 5 ? "20% discount" :
                                 se.Guests.Select(g => g.GuestId).Distinct().Count() >= 1 ? "10% discount" :
                                 "No Discount"
            })
            .ToList();

        return Ok(discounts);
    }

}