using Microsoft.AspNetCore.Identity;
using Microsoft.AspNetCore.Identity.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore;
using WebAPI.Models;

namespace Database
{
    public class DatabaseContext : IdentityDbContext<ApplicationUser>
    {
        public DatabaseContext(DbContextOptions options) : base(options)
        {

        }

        public DbSet<Guest> Guests { get; set; }
        public DbSet<Provider> Providers { get; set; }
        public DbSet<Experience> Experiences { get; set; }
        public DbSet<SharedExperience> SharedExperiences { get; set; }

        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
            base.OnModelCreating(modelBuilder);
            //Seed roles
            modelBuilder.Entity<IdentityRole>().HasData(
                new IdentityRole { Id = "1", Name = "Admin", NormalizedName = "ADMIN" },
                new IdentityRole { Id = "2", Name = "Manager", NormalizedName = "MANAGER" },
                new IdentityRole { Id = "3", Name = "Provider", NormalizedName = "PROVIDER" },
                new IdentityRole { Id = "4", Name = "Guest", NormalizedName = "GUEST" }
            );

            // Many-to-Many between Guest and SharedExperience
            modelBuilder.Entity<Guest>()
                .HasMany(g => g.SharedExperiences)
                .WithMany(se => se.Guests)
                .UsingEntity<Dictionary<string, object>>(
                    "GuestSharedExperience",  // This is the actual junction table in DB
                    j => j.HasOne<SharedExperience>().WithMany().HasForeignKey("SharedExperiencesSharedExperienceId"),
                    j => j.HasOne<Guest>().WithMany().HasForeignKey("GuestsGuestId")
                );


            // Many-to-Many between Experience and SharedExperience
            modelBuilder.Entity<Experience>()
                .HasMany(e => e.SharedExperiences)
                .WithMany(se => se.Experiences)
                .UsingEntity<Dictionary<string, object>>(
                    "ExperienceSharedExperience",  // This is the actual junction table in DB
                    j => j.HasOne<SharedExperience>().WithMany().HasForeignKey("SharedExperiencesSharedExperienceId"),
                    j => j.HasOne<Experience>().WithMany().HasForeignKey("ExperiencesExperienceId")
                );
        }


    }
}