using Database;
using Microsoft.AspNetCore.Identity;
using WebAPI.Models;

namespace Assignment2_EFCore
{
    public class SeedData
    {
        public void Seed(DatabaseContext context)
        {
            context.RemoveRange(context.Experiences);
            context.RemoveRange(context.Guests);
            context.RemoveRange(context.Providers);
            context.RemoveRange(context.SharedExperiences);

            // Experience Providers
            var NoahHotel = new Provider
            {
                Name = "Noah’s Hotel",
                PhoneNumber = "+4571555080",
                Address = "Finlandsgade 17, 8200 Aarhus N",
                Permission = true
            };
            var RyanAir = new Provider
            {
                Name = "Ryanair",
                PhoneNumber = "+4512345678",
                Address = "Billundgade 17, 8200 Aarhus N",
                Permission = false
            };
            var SightSeeing = new Provider
            {
                Name = "SightSeeing",
                PhoneNumber = "+4512345678",
                Address = "Verdensgade 17, 8200 Aarhus N",
                Permission = true
            };

            // Experiences
            var experiences = new List<Experience>
            {
                new Experience ("Night at Noah’s Hotel Single room",  730.50m, NoahHotel ),
                new Experience ( "Night at Noah’s Hotel Double room", 910.99m, NoahHotel ),
                new Experience ( "Flight AAR - VIE", 1000.70m, RyanAir),
                new Experience ( "Vienna Historic Center Walking Tour", 100.00m, SightSeeing)
            };

            // Shared Experiences
            var sharedExperiences = new List<SharedExperience>
            {
                new SharedExperience { Name = "Trip to Austria", Date = new DateTime(2024, 07, 02) },
                new SharedExperience { Name = "Dinner Downtown", Date = new DateTime(2024, 04, 07) },
                new SharedExperience { Name = "Pottery Weekend", Date = new DateTime(2024, 03, 22) }
            };

            // Guests
            var guests = new List<Guest>
            {
                new Guest { Name = "Joan" },
                new Guest { Name = "Suzzane" },
                new Guest { Name = "Patrick" },
                new Guest { Name = "Anne" }
            };

            // Add the shared experiences to the guests
            guests[0].SharedExperiences.Add(sharedExperiences[0]); // Joan is registered to "Trip to Austria"
            guests[1].SharedExperiences.Add(sharedExperiences[0]); // Suzzane is registered to "Trip to Austria"
            guests[2].SharedExperiences.Add(sharedExperiences[0]); // Patrick is registered to "Trip to Austria"
            guests[3].SharedExperiences.Add(sharedExperiences[0]); // Anne is registered to "Trip to Austria"


            // Add the experiences to the guests
            guests[0].Experiences.Add(experiences[3]); // Joan has booked "Vienna Historic Center Walking Tour"
            guests[1].Experiences.Add(experiences[3]); // Suzzane has booked "Vienna Historic Center Walking Tour"

            guests[0].Experiences.Add(experiences[2]); // Joan has booked "Flight AAR - VIE"
            guests[1].Experiences.Add(experiences[2]); // Suzzane has booked "Flight AAR - VIE"
            guests[2].Experiences.Add(experiences[2]); // Patrick has booked "Flight AAR - VIE"
            guests[3].Experiences.Add(experiences[2]); // Anne has booked "Flight AAR - VIE"

            guests[0].Experiences.Add(experiences[0]); // Joan has booked "Night at Noah’s Hotel Single room"
            guests[1].Experiences.Add(experiences[0]); // Suzzane has booked "Night at Noah’s Hotel Single room"
            guests[2].Experiences.Add(experiences[0]); // Patrick has booked "Night at Noah’s Hotel Single room"
            guests[3].Experiences.Add(experiences[0]); // Anne has booked "Night at Noah’s Hotel Single room"

            // Add the experiences to the shared experiences
            sharedExperiences[0].Experiences.Add(experiences[0]); // "Trip to Austria" includes "Night at Noah’s Hotel Single room"
            sharedExperiences[0].Experiences.Add(experiences[2]); // "Trip to Austria" includes "Flight AAR - VIE"
            sharedExperiences[0].Experiences.Add(experiences[3]); // "Trip to Austria" includes "Vienna Historic Center Walking Tour"


            // Add entities to the context
            context.Providers.AddRange(NoahHotel, RyanAir, SightSeeing);
            context.Experiences.AddRange(experiences);
            context.SharedExperiences.AddRange(sharedExperiences);
            context.Guests.AddRange(guests);

            // Save changes to the database
            context.SaveChanges();
        }
        public static async Task SeedRolesAndUsers(UserManager<ApplicationUser> userManager, RoleManager<IdentityRole> roleManager)
        {
            // Ensure all roles and users are deleted
            var users = userManager.Users.ToList();
            foreach (var user in users)
            {
                await userManager.DeleteAsync(user);
            }


            // Ensure roles exist
            string[] roles = { "Admin", "Manager", "Provider", "Guest" };
            foreach (var role in roles)
            {
                if (!await roleManager.RoleExistsAsync(role))
                {
                    await roleManager.CreateAsync(new IdentityRole(role));
                }
            }

            // Create Manager user
            if (await userManager.FindByEmailAsync("manager@test.com") == null)
            {
                var managerUser = new ApplicationUser { UserName = "manager", Email = "manager@test.com", EmailConfirmed = true };
                var result = await userManager.CreateAsync(managerUser, "1234");

                if (result.Succeeded)
                {
                    await userManager.AddToRoleAsync(managerUser, "Manager");
                }
            }

            // Create Admin user
            if (await userManager.FindByEmailAsync("admin@test.com") == null)
            {
                var adminUser = new ApplicationUser { UserName = "admin", Email = "admin@test.com", EmailConfirmed = true };
                var result = await userManager.CreateAsync(adminUser, "1234");

                if (result.Succeeded)
                {
                    await userManager.AddToRoleAsync(adminUser, "Admin");
                }
            }

            // Create Provider user
            if (await userManager.FindByEmailAsync("provider@test.com") == null)
            {
                var providerUser = new ApplicationUser { UserName = "provider", Email = "provider@test.com", EmailConfirmed = true };
                var result = await userManager.CreateAsync(providerUser, "1234");

                if (result.Succeeded)
                {
                    await userManager.AddToRoleAsync(providerUser, "Provider");
                }
            }

            // Create Guest user
            if (await userManager.FindByEmailAsync("guest@test.com") == null)
            {
                var guestUser = new ApplicationUser { UserName = "guest", Email = "guest@test.com", EmailConfirmed = true };
                var result = await userManager.CreateAsync(guestUser, "1234");

                if (result.Succeeded)
                {
                    await userManager.AddToRoleAsync(guestUser, "Guest");
                }
            }
        }
    }


}