using Database;
using WebAPI.Models;

namespace WebAPI.Services;

public class GuestService
{
    private readonly DatabaseContext _context;

    public GuestService(DatabaseContext context)
    {
        _context = context;
    }

    public List<Guest> GetAll()
    {
        return _context.Guests.ToList();
    }


    // Get all guests registered for a specific shared experience
    public List<Guest> GetGuestsForSharedExperience(string sharedExperienceName)
    {
        return _context.Guests
            .Where(g => g.SharedExperiences.Any(se => se.Name == sharedExperienceName))
            .ToList();
    }

    // Get all the guests registered for one of the experiences in a shared experience.
    public List<Guest> GetGuestsForExperience(string experienceName)
    {
        return _context.Guests
            .Where(g => g.Experiences.Any(ex => ex.Name == experienceName))
            .ToList();
    }

}
